@@ -27,12 +27,12 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KPropertiesDialog>
-#include <KRun>
 
 #include <KIO/CopyJob>
 #include <KIO/DeleteJob>
 #include <KIO/JobUiDelegate>
 #include <KIO/OpenFileManagerWindowJob>
+#include <KIO/OpenUrlJob>
 #include <kio_version.h>
 
 // Permission strings
@@ -184,7 +184,7 @@ QMimeData *KFindItemModel::mimeData(const QModelIndexList &indexes) const
 {
     QList<QUrl> uris;
 
-    foreach (const QModelIndex &index, indexes) {
+    for (const QModelIndex &index : indexes) {
         if (index.isValid()) {
             if (index.column() == 0) { //Only use the first column item
                 uris.append(m_itemList.at(index.row()).getFileItem().url());
@@ -300,7 +300,7 @@ bool KFindSortFilterProxyModel::lessThan(const QModelIndex &left, const QModelIn
 
 KFindTreeView::KFindTreeView(QWidget *parent, KfindDlg *findDialog)
     : QTreeView(parent)
-    , m_contextMenu(Q_NULLPTR)
+    , m_contextMenu(nullptr)
     , m_kfindDialog(findDialog)
 {
     //Configure model and proxy model
@@ -492,8 +492,7 @@ void KFindTreeView::saveResults()
                                           "<meta charset=\"%1\">\n"
                                           "<body>\n<h1>%2</h1>\n"
                                           "<dl>\n")
-                .arg(QString::fromLatin1(QTextCodec::codecForLocale()->name()))
-                .arg(i18n("KFind Results File"));
+                .arg(QString::fromLatin1(QTextCodec::codecForLocale()->name()), i18n("KFind Results File"));
 
             for (const KFindItem &item : itemList) {
                 const KFileItem fileItem = item.getFileItem();
@@ -503,13 +502,7 @@ void KFindTreeView::saveResults()
             stream << QStringLiteral("</dl>\n</body>\n</html>\n");
         } else {
             for (const KFindItem &item : itemList) {
-                stream << item.getFileItem().url().url()
-          #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                       << endl
-          #else
-                       << Qt::endl
-          #endif
-                          ;
+                stream << item.getFileItem().url().url() << Qt::endl;
             }
         }
 
@@ -531,11 +524,13 @@ void KFindTreeView::slotExecuteSelected()
     }
 
     //TODO if >X add a warn ?
-    Q_FOREACH (const QModelIndex &index, selected) {
+    for (const QModelIndex &index : selected) {
         if (index.column() == 0) {
             KFindItem item = m_model->itemAtIndex(index);
             if (item.isValid()) {
-                new KRun(item.getFileItem().targetUrl(), this);
+                auto *job = new KIO::OpenUrlJob(item.getFileItem().targetUrl());
+                job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+                job->start();
             }
         }
     }
@@ -543,7 +538,7 @@ void KFindTreeView::slotExecuteSelected()
 
 void KFindTreeView::slotExecute(const QModelIndex &index)
 {
-    if ((m_mouseButtons &Qt::LeftButton) && QApplication::keyboardModifiers() == Qt::NoModifier) {
+    if ((m_mouseButtons & Qt::LeftButton) && QApplication::keyboardModifiers() == Qt::NoModifier) {
         if (!index.isValid()) {
             return;
         }
@@ -553,9 +548,11 @@ void KFindTreeView::slotExecute(const QModelIndex &index)
             return;
         }
 
-        KFindItem item = m_model->itemAtIndex(realIndex);
+        const KFindItem item = m_model->itemAtIndex(realIndex);
         if (item.isValid()) {
-            new KRun(item.getFileItem().targetUrl(), this);
+            auto *job = new KIO::OpenUrlJob(item.getFileItem().targetUrl());
+            job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+            job->start();
         }
     }
 }
@@ -569,7 +566,7 @@ void KFindTreeView::contextMenuRequested(const QPoint &p)
         return;
     }
 
-    Q_FOREACH (const QModelIndex &index, selected) {
+    for (const QModelIndex &index : selected) {
         if (index.column() == 0) {
             const KFindItem item = m_model->itemAtIndex(index);
             if (item.isValid()) {
@@ -593,9 +590,7 @@ void KFindTreeView::contextMenuRequested(const QPoint &p)
     menuActions.setItemListProperties(fileProperties);
     menuActions.addOpenWithActionsTo(m_contextMenu);
     // 'Actions' submenu
-    menuActions.addServiceActionsTo(m_contextMenu);
-    // Plugins
-    menuActions.addPluginActionsTo(m_contextMenu);
+    menuActions.addActionsTo(m_contextMenu);
 
     m_contextMenu->addSeparator();
 
@@ -617,7 +612,7 @@ QList<QUrl> KFindTreeView::selectedUrls()
     QList<QUrl> uris;
 
     const QModelIndexList indexes = m_proxyModel->mapSelectionToSource(selectionModel()->selection()).indexes();
-    Q_FOREACH (const QModelIndex &index, indexes) {
+    for (const QModelIndex &index : indexes) {
         if (index.column() == 0 && index.isValid()) {
             KFindItem item = m_model->itemAtIndex(index);
             if (item.isValid()) {
