@@ -35,7 +35,6 @@ KQuery::KQuery(QObject *parent)
     , m_recursive(false)
     , m_casesensitive(false)
     , m_search_binary(false)
-    , m_regexpForContent(false)
     , m_useLocate(false)
     , m_showHiddenFiles(false)
     , job(nullptr)
@@ -172,22 +171,22 @@ void KQuery::checkEntries()
         /* This is a workaround. As the qApp->processEvents() call inside processQuery
          * will bring more KIO entries, m_fileItems will increase even inside this loop
          * and that will lead to a big loop, it will take time to report found items to the GUI
-         * so we are going to force emit results every 100 files processed */
+         * so we are going to force Q_EMIT results every 100 files processed */
         if (processingCount == 100) {
             processingCount = 0;
             if (m_foundFilesList.size() > 0) {
-                emit foundFileList(m_foundFilesList);
+                Q_EMIT foundFileList(m_foundFilesList);
                 m_foundFilesList.clear();
             }
         }
     }
 
     if (m_foundFilesList.size() > 0) {
-        emit foundFileList(m_foundFilesList);
+        Q_EMIT foundFileList(m_foundFilesList);
     }
 
     if (job == nullptr) {
-        emit result(m_result);
+        Q_EMIT result(m_result);
     }
 
     m_insideCheckEntries = false;
@@ -208,7 +207,7 @@ void KQuery::slotListEntries(const QStringList &list)
     }
 
     if (!m_foundFilesList.isEmpty()) {
-        emit foundFileList(m_foundFilesList);
+        Q_EMIT foundFileList(m_foundFilesList);
     }
 }
 
@@ -340,9 +339,9 @@ void KQuery::processQuery(const KFileItem &file)
         QString strmetakeycontent;
 
         KFileMetaData::ExtractorCollection extractors;
-        QList<KFileMetaData::Extractor*> exList = extractors.fetchExtractors(mimetype);
+        const QList<KFileMetaData::Extractor*> exList = extractors.fetchExtractors(mimetype);
 
-        Q_FOREACH (KFileMetaData::Extractor* ex, exList) {
+        for (KFileMetaData::Extractor* ex : exList) {
             KFileMetaData::SimpleExtractionResult result(filename, mimetype,
                                                          KFileMetaData::ExtractionResult::ExtractMetaData);
             ex->extract(&result);
@@ -458,19 +457,11 @@ void KQuery::processQuery(const KFileItem &file)
                 str.remove(xmlTags);
             }
 
-            if (m_regexpForContent) {
-                if (m_regexp.indexIn(str) >= 0) {
-                    matchingLine = QString::number(matchingLineNumber)+QStringLiteral(": ")+str.trimmed();
-                    found = true;
-                    break;
-                }
-            } else {
-                if (str.indexOf(m_context, 0, m_casesensitive ? Qt::CaseSensitive : Qt::CaseInsensitive) != -1) {
-                    matchingLine = QString::number(matchingLineNumber)+QStringLiteral(": ")+str.trimmed();
-                    found = true;
-                    break;
-                }
-            }
+	if (str.indexOf(m_context, 0, m_casesensitive ? Qt::CaseSensitive : Qt::CaseInsensitive) != -1) {
+	    matchingLine = QString::number(matchingLineNumber)+QStringLiteral(": ")+str.trimmed();
+	    found = true;
+	    break;
+	}
             qApp->processEvents();
         }
 
@@ -484,25 +475,17 @@ void KQuery::processQuery(const KFileItem &file)
     m_foundFilesList.append(QPair<KFileItem, QString>(file, matchingLine));
 }
 
-void KQuery::setContext(const QString &context, bool casesensitive, bool search_binary, bool useRegexp)
+void KQuery::setContext(const QString &context, bool casesensitive, bool search_binary)
 {
     m_context = context;
     m_casesensitive = casesensitive;
     m_search_binary = search_binary;
-    m_regexpForContent = useRegexp;
-    if (!m_regexpForContent) {
-        m_regexp.setPatternSyntax(QRegExp::Wildcard);
-    } else {
-        m_regexp.setPatternSyntax(QRegExp::RegExp);
-    }
+    m_regexp.setPatternSyntax(QRegExp::Wildcard);
     if (casesensitive) {
         m_regexp.setCaseSensitivity(Qt::CaseSensitive);
     } else {
         m_regexp.setCaseSensitivity(Qt::CaseInsensitive);
     }
-    if (m_regexpForContent) {
-        m_regexp.setPattern(m_context);
-    }
 }
 
 void KQuery::setMetaInfo(const QString &metainfo, const QString &metainfokey)
@@ -548,11 +531,7 @@ void KQuery::setRegExp(const QString &regexp, bool caseSensitive)
 {
     QRegExp *regExp = nullptr;
     QRegExp sep(QStringLiteral(";"));
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList strList = regexp.split(sep, QString::SkipEmptyParts);
-#else
     const QStringList strList = regexp.split(sep, Qt::SkipEmptyParts);
-#endif
     //  QRegExp globChars ("[\\*\\?\\[\\]]", TRUE, FALSE);
     while (!m_regexps.isEmpty()) {
         delete m_regexps.takeFirst();
@@ -602,12 +581,8 @@ void KQuery::slotendProcessLocate(int code, QProcess::ExitStatus)
         if (!bufferLocate.isEmpty()) {
             QString str = QString::fromLocal8Bit(bufferLocate);
             bufferLocate.clear();
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            slotListEntries(str.split(QLatin1Char('\n'), QString::SkipEmptyParts));
-#else
             slotListEntries(str.split(QLatin1Char('\n'), Qt::SkipEmptyParts));
-#endif
         }
     }
-    emit result(0);
+    Q_EMIT result(0);
 }
